@@ -1,9 +1,9 @@
 import requests
 
-from celery import task
+from celery import shared_task
 
 
-@task(ignore_result=True)
+@shared_task(ignore_result=True)
 def send_ga_tracking(params):
     utm_url = params.get('utm_url')
     user_agent = params.get('user_agent')
