@@ -23,9 +23,12 @@ class GoogleAnalyticsTestCase(TestCase):
         We don't have any normal views, so we're creating fake
         views using django's RequestFactory
         """
+        def mock_view(request):
+            return HttpResponse("")
+
         rf = RequestFactory()
         request = rf.get(url, **headers)
-        session_middleware = SessionMiddleware()
+        session_middleware = SessionMiddleware(mock_view)
         session_middleware.process_request(request)
         request.session.save()
         return request
@@ -144,7 +147,7 @@ class GoogleAnalyticsTestCase(TestCase):
     @responses.activate
     def test_ga_middleware(self):
         responses.add(
-            responses.GET, 'http://www.google-analytics.com/collect',
+            responses.GET, 'https://www.google-analytics.com/collect',
             body='',
             status=200)
 
@@ -186,7 +189,7 @@ class GoogleAnalyticsTestCase(TestCase):
     @responses.activate
     def test_ga_middleware_pre_dj110(self):
         responses.add(
-            responses.GET, 'http://www.google-analytics.com/collect',
+            responses.GET, 'https://www.google-analytics.com/collect',
             body='',
             status=200)
 
@@ -227,7 +230,7 @@ class GoogleAnalyticsTestCase(TestCase):
     @responses.activate
     def test_build_ga_params_for_title_encoding(self):
         responses.add(
-            responses.GET, 'http://www.google-analytics.com/collect',
+            responses.GET, 'https://www.google-analytics.com/collect',
             body='',
             status=200)
 
@@ -386,7 +389,7 @@ class GoogleAnalyticsTestCase(TestCase):
     @responses.activate
     def test_ga_middleware_no_title(self):
         responses.add(
-            responses.GET, 'http://www.google-analytics.com/collect',
+            responses.GET, 'https://www.google-analytics.com/collect',
             body='',
             status=200)
 
